@@ -20,7 +20,7 @@ class SearchField(object):
     def __init__(self, model_attr=None, use_template=False, template_name=None,
                  document=False, indexed=True, stored=True, faceted=False,
                  default=NOT_PROVIDED, null=False, index_fieldname=None,
-                 facet_class=None, weight=1.0):
+                 facet_class=None, boost=1.0, weight=None):
         # Track what the index thinks this field is called.
         self.instance_name = None
         self.model_attr = model_attr
@@ -33,7 +33,7 @@ class SearchField(object):
         self._default = default
         self.null = null
         self.index_fieldname = index_fieldname
-        self.weight = weight
+        self.boost = weight or boost
         self.is_multivalued = False
         
         # We supply the facet_class for making it easy to create a faceted
@@ -158,6 +158,20 @@ class CharField(SearchField):
         return unicode(value)
 
 
+class NgramField(CharField):
+    field_type = 'ngram'
+    
+    def __init__(self, **kwargs):
+        if kwargs.get('faceted') is True:
+            raise SearchFieldError("%s can not be faceted." % self.__class__.__name__)
+        
+        super(NgramField, self).__init__(**kwargs)
+
+
+class EdgeNgramField(NgramField):
+    field_type = 'edge_ngram'
+
+
 class IntegerField(SearchField):
     field_type = 'integer'
     
@@ -272,6 +286,9 @@ class MultiValueField(SearchField):
         if kwargs.get('facet_class') is None:
             kwargs['facet_class'] = FacetMultiValueField
         
+        if kwargs.get('use_template') is True:
+            raise SearchFieldError("'%s' fields can not use templates to prepare their data." % self.__class__.__name__)
+        
         super(MultiValueField, self).__init__(**kwargs)
         self.is_multivalued = True
     
